#include <avr/sleep.h>
#include <avr/interrupt.h>

#define WEMOS_GPIO16_PIN 0
#define WEMOS_RESET_PIN 1
#define STATUS_LED_PIN 2
#define TILT_SWITCH_PIN 3

long last_wakeup;

void setup() {
  pinMode(WEMOS_GPIO16_PIN, INPUT);
  pinMode(WEMOS_RESET_PIN, OUTPUT);
  pinMode(TILT_SWITCH_PIN, INPUT_PULLUP);
  pinMode(STATUS_LED_PIN, OUTPUT);

  // let the WEMOS wake up
}

void loop() {
  delay(2000);
  // wait until WEMOS finishes its business, then go to sleep again
  while(!digitalRead(WEMOS_GPIO16_PIN)) {
    digitalWrite(STATUS_LED_PIN, HIGH);
    delay(1);
    digitalWrite(STATUS_LED_PIN, LOW);
    delay(300);
  }

  // go to sleep until tilt switch wakes you up
  sleep();
  
  // wake up, WEMOS!
  digitalWrite(WEMOS_RESET_PIN, HIGH);
  delay(10);
  digitalWrite(WEMOS_RESET_PIN, LOW);
}


void sleep() {
  GIMSK |= _BV(PCIE);                     // Enable Pin Change Interrupts
  PCMSK |= _BV(PCINT3);                   // Use PB3 as interrupt pin
  ADCSRA &= ~_BV(ADEN);                   // ADC off
  set_sleep_mode(SLEEP_MODE_PWR_DOWN);    // replaces above statement

  sleep_enable();                         // Sets the Sleep Enable bit in the MCUCR Register (SE BIT)
  sei();                                  // Enable interrupts
  sleep_cpu();                            // sleep

  cli();                                  // Disable interrupts
  PCMSK &= ~_BV(PCINT3);                  // Turn off PB3 as interrupt pin
  sleep_disable();                        // Clear SE bit
  ADCSRA |= _BV(ADEN);                    // ADC on

  sei();                                  // Enable interrupts
} // sleep

ISR(PCINT0_vect) {
  // This is called when the interrupt occurs, but I don't need to do anything in it
}


